@@ -40,9 +40,9 @@ class CostSensitiveFlagging(module.Module):
     review costs used by this module by specifying a value for the `fp_cost`,
     `fn_cost`, and `human_review_cost` attributes::
 
-        instance.metadata['flagging']['fp_cost'] = 100
-        instance.metadata['flagging']['fn_cost'] = 300
-        instance.metadata['flagging']['human_review_cost'] = 10
+        instance.instance_metadata['flagging']['fp_cost'] = 100
+        instance.instance_metadata['flagging']['fn_cost'] = 300
+        instance.instance_metadata['flagging']['human_review_cost'] = 10
 
     The costs specified as part of the instance will always be used over
     the costs specified for this module.
@@ -87,13 +87,13 @@ class CostSensitiveFlagging(module.Module):
         # If the instance comes with specific costs, we want to use those
         # instead of the costs specified on this module.
         fp_cost = instance.get_attribute(
-            f"metadata.{PIPELINE_MODULE_NAME}.fp_cost", default=self.fp_cost
+            f"instance_metadata.{PIPELINE_MODULE_NAME}.fp_cost", default=self.fp_cost
         )
         fn_cost = instance.get_attribute(
-            f"metadata.{PIPELINE_MODULE_NAME}.fn_cost", default=self.fn_cost
+            f"instance_metadata.{PIPELINE_MODULE_NAME}.fn_cost", default=self.fn_cost
         )
         human_review_cost = instance.get_attribute(
-            f"metadata.{PIPELINE_MODULE_NAME}.human_review_cost",
+            f"instance_metadata.{PIPELINE_MODULE_NAME}.human_review_cost",
             default=self.human_review_cost,
         )
 
