@@ -32,13 +32,14 @@ class Notification(Connection):
         ) as file:
             template = file.read()
 
-        variables_pattern = re.compile(r"\[\[(.*\]*\[*)\]\]")
+        variables_pattern = re.compile(r"(\[\[.+?\]\])")
 
         variables = variables_pattern.findall(template)
         for variable in variables:
-            value = str(instance.get_attribute(variable, default=""))
-            logging.info(f"Replacing variable {variable} with value {value}")
-            template = template.replace(f"[[{variable}]]", value)
+            variable_name = variable[2:-2]
+            value = str(instance.get_attribute(variable_name, default=""))
+            logging.info(f"Replacing variable {variable_name} with value {value}")
+            template = template.replace(f"{variable}", value)
 
         logging.info(f"Final template: \n{template}")
 
