@@ -6,12 +6,13 @@ import importlib.util
 import redis
 import re
 
+from datetime import datetime
 from rq import Queue, Retry
 from importlib import import_module
 
 from alira.instance import Instance
 from alira.modules.module import InternalError
-from alira.store import Store
+from alira.common.database import Database
 
 rq_worker_logger = logging.getLogger("rq.worker")
 
@@ -24,18 +25,18 @@ class Pipeline(object):
         self,
         pipeline_configuration: any = None,
         configuration_directory: str = None,
-        store_configuration: dict = None,
         redis_server: str = None,
+        mysql_server: str = None,
         asynchronous: bool = True,
-        **kwargs,
+        **kwargs
     ):
         self.kwargs = kwargs
 
         self.configuration_directory = configuration_directory or os.path.abspath(
             os.getcwd()
         )
-        self.store_configuration = store_configuration
         self.redis_server = redis_server or "redis://localhost:6379/"
+        self.mysql_server = mysql_server
         self.asynchronous = asynchronous
 
         # We are going to read the pipeline identifier and the list of
@@ -47,13 +48,12 @@ class Pipeline(object):
         self._load_pipeline_configuration(pipeline_configuration)
 
     def run(self, data: dict) -> Instance:
+        data.update({"pipeline_id": self.pipeline_id})
         instance = Instance.create(data)
 
-        store = Store.configure(
-            configuration_directory=self.configuration_directory,
-            store_configuration=self.store_configuration,
-        )
-        store.put(instance)
+        database = Database(self.mysql_server)
+        database.instance_dao().put(instance)
+        database.flat_instance_metadata_dao(self.pipeline_id).put(instance)
 
         if self.asynchronous:
             redis_connection = redis.from_url(self.redis_server)
@@ -87,17 +87,14 @@ class Pipeline(object):
                 module_signature=module_signature,
                 instance=instance,
                 dependencies=self.dependencies,
-                store_configuration=self.store_configuration,
                 pipeline_id=self.pipeline_id,
                 configuration_directory=self.configuration_directory,
-                **arguments,
+                database=database,
+                **arguments
             )
 
-        # At this point, we need to refresh the store to load any changes that
-        # might have happened during the execution of the pipeline.
-        store.refresh()
-
-        return store.get(instance.id) or instance
+        instance_row = database.instance_dao().get_instance(instance_id=instance.instance_id)
+        return Instance.create_from_row(instance_row) if instance_row else instance
 
     @classmethod
     def run_module(
@@ -106,20 +103,16 @@ class Pipeline(object):
         module_signature,
         instance,
         dependencies,
-        store_configuration,
         pipeline_id,
         configuration_directory,
+        database,
     ):
         rq_worker_logger.info(f"Running module {module_signature}...")
 
-        store = Store.configure(
-            configuration_directory=configuration_directory,
-            store_configuration=store_configuration,
-        )
-
         Pipeline.load_pipeline_python_file(pipeline_id, configuration_directory)
+        instance_row = database.instance_dao().get_instance(instance_id=instance.instance_id)
+        instance = Instance.create_from_row(instance_row) if instance_row else instance
 
-        instance = store.get(instance.id) or instance
         rq_worker_logger.debug(f"Input instance: {instance.to_dict()}")
         rq_worker_logger.debug(f"Dependencies: {dependencies}")
 
@@ -143,9 +136,13 @@ class Pipeline(object):
             rq_worker_logger.exception(error)
             module_output = {module_name: error}
 
-        instance = store.get(instance.id) or instance
-        instance.properties.update(module_output)
-        store.put(instance)
+        # Load the instance again to avoid overwriting another asynchronous module's data
+        instance_row = database.instance_dao().get_instance(instance_id=instance.instance_id)
+        instance = Instance.create_from_row(instance_row) if instance_row else instance
+
+        instance.instance_properties.update(module_output)
+        instance.last_update_date = datetime.utcnow().isoformat()
+        database.instance_dao().put(instance)
 
         rq_worker_logger.debug(f"Output instance: {instance.to_dict()}")
         return module_output
